Skip to contents

Loads prior distributions and MCMC results from disk, generates parameter samples for ensemble and sensitivity analysis runs, and saves results to samples.Rdata.

Usage

get.parameter.samples(
  settings,
  ensemble.size = 1,
  posterior.files = rep(NA, length(settings$pfts)),
  ens.sample.method = "uniform",
  save_to_disk = TRUE
)

Arguments

settings

PEcAn settings object

ensemble.size

number of runs in model ensemble

posterior.files

list of filenames to read from

ens.sample.method

one of "halton", "sobol", "torus", "lhc", "uniform"

save_to_disk

logical. If TRUE (default), saves samples.Rdata.

Value

named list with: trait.samples, sa.samples, ensemble.samples, runs.samples, env.samples

Details

This is the backward-compatible wrapper. Delegates computation to get_parameter_samples.

Author

David LeBauer, Shawn Serbin, Istem Fer, Om Kapale