Skip to contents

Function for generating samples based on sampling method, parent or etc

Usage

input.ens.gen(
  settings,
  ensemble_size,
  input,
  method = "sampling",
  parent_ids = NULL
)

Arguments

settings

list of PEcAn settings

ensemble_size

size of ensemble

input

name of input to sample, e.g. "met", "veg", "pss"

method

Method for sampling - For now looping or sampling with replacement is implemented

parent_ids

This is basically the order of the paths that the parent is sampled.See Details.

Value

For a given input/tag in the pecan xml and a method, this function returns a list with $id showing the order of sampling and $samples with samples of that input.

Details

If for example met was a parent and it's sampling method resulted in choosing the first, third and fourth samples, these are the ids that need to be sent as parent_ids to this function.

Examples

if (FALSE) { # \dontrun{
  settings <- PEcAn.settings::read.settings("pecan.xml")
  input.ens.gen(
    settings, 
    ensemble_size = 50,
    input = "met",
    method = "sampling"
  )
} # }