Function for generating samples based on sampling method, parent or etc
Source:R/ensemble.R
input.ens.gen.RdFunction for generating samples based on sampling method, parent or etc
Value
For a given input/tag in the pecan xml and a method, this function returns a list with $id showing the order of sampling and $samples with samples of that input.
Details
If for example met was a parent and it's sampling method resulted in choosing the first, third and fourth samples, these are the ids that need to be sent as parent_ids to this function.
Examples
if (FALSE) { # \dontrun{
settings <- PEcAn.settings::read.settings("pecan.xml")
input.ens.gen(
settings,
ensemble_size = 50,
input = "met",
method = "sampling"
)
} # }